@@ -247,6 +247,10 @@ public:
     
     FrameBuffer Backward(FrameBuffer dy_buf) override
     {
+        if (dy_buf.Empty()) {
+            return dy_buf;
+        }
+
         BB_ASSERT(dy_buf.GetType() == DataType<BT>::type);
 
         index_t output_frame_size = dy_buf.GetFrameSize();
