@@ -51,6 +51,7 @@ protected:
     bool                        m_lut_binarize = false;
     bool                        m_binary_mode  = true;
     bool                        m_batch_norm   = true;
+    bool                        m_backward_break = false;
 
     bool                        m_flagClamp = false;
 
@@ -90,7 +91,7 @@ public:
         bool            batch_norm = true;
         bool            binary     = true;
         std::string     connection;                 //< 結線ルール
-        RealType        momentum   = (RealType)0.0;
+        RealType        momentum   = (RealType)0.9;
         RealType        gamma      = (RealType)0.3;
         RealType        beta       = (RealType)0.5;
         std::uint64_t   seed       = 1;              //< 乱数シード
@@ -122,7 +123,7 @@ protected:
     void CommandProc(std::vector<std::string> args)
     {
         _super::CommandProc(args);
-
+        
         // バイナリモード設定
         if ( DataType<BinType>::type != BB_TYPE_BIT ) {
             if ( args.size() == 2 && args[0] == "binary" )
@@ -143,11 +144,23 @@ protected:
             m_host_only = EvalBool(args[1]);
         }
 
-        // HostOnlyモード設定
+        // batch_norm設定
+        if (args.size() == 2 && args[0] == "batch_norm")
+        {
+            m_batch_norm = EvalBool(args[1]);
+        }
+
+        // momentum設定
         if (args.size() == 2 && args[0] == "momentum")
         {
             m_momentum = (RealType)EvalReal(args[1]);
         }
+
+        // backward_break
+        if (args.size() == 2 && args[0] == "backward_break")
+        {
+            m_backward_break = EvalBool(args[1]);
+        }
     }
     
     void PrintInfoText(std::ostream& os, std::string indent, int columns, int nest, int depth) const override
@@ -967,6 +980,11 @@ public:
 
     FrameBuffer Backward(FrameBuffer dy_buf)
     {
+        if (m_backward_break || dy_buf.Empty()) {
+            m_dW = 0;
+            return FrameBuffer();
+        }
+
         BB_ASSERT(dy_buf.GetType() == DataType<RealType>::type);
 
         m_flagClamp = true;
@@ -988,6 +1006,14 @@ public:
         FrameBuffer tmp_buf(tmp_frame_size, {output_node_size*N}, DataType<RealType>::type);
 
         if ( m_batch_norm ) {
+            auto mean = m_mean;
+            auto rstd = m_rstd;
+
+            if ( this->m_parameter_lock ) {
+                mean = m_running_mean + 0;
+                rstd = (RealType)1.0 / (m_running_var + (RealType)1.0e-7).Sqrt();
+            }
+
             // with BatchNormalization
     #ifdef BB_WITH_CUDA
             // CUDA float
@@ -1005,11 +1031,11 @@ public:
                 auto input_table_ptr   = m_connection_table.LockDeviceMemConst_InputTable();
                 auto W_ptr             = m_W->LockDeviceMemoryConst();
                 auto dW_ptr            = m_dW->LockDeviceMemory();
-                auto mean_ptr          = m_mean.LockDeviceMemoryConst();
-                auto rstd_ptr          = m_rstd.LockDeviceMemoryConst();
+                auto mean_ptr          = mean.LockDeviceMemoryConst();
+                auto rstd_ptr          = rstd.LockDeviceMemoryConst();
                 auto dmean_ptr         = dmean.LockDeviceMemory(true);
                 auto dvar_ptr          = dvar.LockDeviceMemory(true);
-            
+                
                 bbcu_fp32_DifferentiableLutN_Backward<N>
                     (
                         (float const *)x_ptr.GetAddr(),
