@@ -366,6 +366,10 @@ public:
     
     FrameBuffer Backward(FrameBuffer dy_buf) override
     {
+        if (dy_buf.Empty()) {
+            return dy_buf;
+        }
+
         BB_ASSERT(dy_buf.GetType() == DataType<BT>::type);
 
         FrameBuffer dx_buf(dy_buf.GetFrameSize(), m_input_shape, DataType<BT>::type);
