@@ -59,7 +59,8 @@ BBCU_DLL_EXPORT bool bbcu_IsDeviceAvailable(void);
 BBCU_DLL_EXPORT void  *bbcu_LocalHeap_Malloc(size_t size);
 BBCU_DLL_EXPORT void   bbcu_LocalHeap_Free(void* ptr);
 BBCU_DLL_EXPORT size_t bbcu_LocalHeap_GetMaxAllocSize(void);
-
+BBCU_DLL_EXPORT size_t bbcu_LocalHeap_GetAllocatedSize(void);
+BBCU_DLL_EXPORT void   bbcu_LocalHeap_GarbageCollect(void);
 
 #if defined(__cplusplus) && defined(BBCU_DLL)
 }
@@ -1313,6 +1314,24 @@ BBCU_DLL_EXPORT int bbcu_bit_BitEncode
         );
 
 
+// -------------------------------------
+//  LossMeanSquaredError
+// -------------------------------------
+
+BBCU_DLL_EXPORT int bbcu_fp32_LossMeanSquaredError
+        (
+            const float*    dev_y_buf,
+            const float*    dev_t_buf,
+            float*          dev_dy_buf,
+            double*         dev_loss_buf,
+            int             loss_buf_size,
+            int             node_size,
+            int             frame_size,
+            int             frame_stride,
+            int             batch_size,
+            cudaStream_t    streamId = 0
+        );
+
 // -------------------------------------
 //  LossSoftmaxCrossEntropy
 // -------------------------------------
